table: attach PIT entry to NameTree node within depth limit

refs #4262

Change-Id: I64d76a337c3b491efa2f93c803046cea70c87000
diff --git a/daemon/table/name-tree.hpp b/daemon/table/name-tree.hpp
index 6d04821..04e504e 100644
--- a/daemon/table/name-tree.hpp
+++ b/daemon/table/name-tree.hpp
@@ -136,10 +136,10 @@
 
 public: // matching
   /** \brief exact match lookup
    *  \return entry with \p name, or nullptr if it does not exist
    */
   Entry*
-  findExactMatch(const Name& name) const;
+  findExactMatch(const Name& name, size_t prefixLen = std::numeric_limits<size_t>::max()) const;
 
   /** \brief longest prefix matching
    *  \return entry whose name is a prefix of \p name and passes \p entrySelector,
@@ -136,10 +136,10 @@
 public: // matching
   /** \brief exact match lookup
-   *  \return entry with \p name, or nullptr if it does not exist
+   *  \return entry with \p name.getPrefix(prefixLen), or nullptr if it does not exist
    */
   Entry*